@@ -1,14 +1,17 @@
-/*********************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import axios from 'axios'
+import { cli } from 'cli-ux'
 import execa = require('execa')
 import * as fs from 'fs-extra'
 import * as https from 'https'
@@ -60,7 +63,7 @@ export namespace VersionHelper {
             throw getMinimalVersionError(actualVersion, MINIMAL_OPENSHIFT_VERSION, 'OpenShift')
           }
         }
-      }
+      },
     }
   }
   export function getK8sCheckVersionTask(flags: any): Listr.ListrTask {
@@ -90,7 +93,7 @@ export namespace VersionHelper {
             throw getMinimalVersionError(actualVersion, MINIMAL_K8S_VERSION, 'Kubernetes')
           }
         }
-      }
+      },
     }
   }
 
@@ -190,7 +193,7 @@ export namespace VersionHelper {
     }
 
     const axiosInstance = axios.create({
-      httpsAgent: new https.Agent({})
+      httpsAgent: new https.Agent({}),
     })
 
     try {
@@ -233,16 +236,34 @@ export namespace VersionHelper {
     }
 
     // Check cache, if it is already known that newer version available
-    const isCachedNewerVersionAvailable = semver.gt(newVersionInfo.latestVersion, currentVersion)
+    let isCachedNewerVersionAvailable = false
+    try {
+      isCachedNewerVersionAvailable = semver.gt(newVersionInfo.latestVersion, currentVersion)
+    } catch (error) {
+      // not a version (corrupted data)
+      cli.debug(`Failed to compare versions '${newVersionInfo.latestVersion}' and '${currentVersion}': ${error}`)
+    }
+
     const now = Date.now()
     const isCacheExpired = now - newVersionInfo.lastCheck > A_DAY_IN_MS
     if (forceRecheck || (!isCachedNewerVersionAvailable && isCacheExpired)) {
       // Cached info is expired. Fetch actual info about versions.
       // undefined cannot be returned from getLatestChectlVersion as 'is flavor' check was done before.
-      const latestVersion = (await getLatestChectlVersion(channel))!
+      const latestVersion = (await getLatestChectlVersion(channel))
+      // if request failed (GitHub endpoint is not available) then
+      // assume update is not available
+      if (!latestVersion) {
+        return false
+      }
       newVersionInfo = { latestVersion, lastCheck: now }
       await fs.writeJson(newVersionInfoFilePath, newVersionInfo, { encoding: 'utf8' })
-      return semver.gt(newVersionInfo.latestVersion, currentVersion)
+      try {
+        return semver.gt(newVersionInfo.latestVersion, currentVersion)
+      } catch (error) {
+        // not to fail unexpectedly
+        cli.debug(`Failed to compare versions '${newVersionInfo.latestVersion}' and '${currentVersion}': ${error}`)
+        return false
+      }
     }
 
     // Information whether a newer version available is already in cache
@@ -253,7 +274,7 @@ export namespace VersionHelper {
    * Indicates if stable version of CodeReady Workspaces is specified or meant implicitly.
    */
   export function isDeployingStableVersion(flags: any): boolean {
-    return !!flags.version || !ChectlContext.get().isNightly
+    return Boolean(flags.version) || !ChectlContext.get().isNightly
   }
 
   /**
