@@ -1,12 +1,14 @@
-/*********************************************************************
- * Copyright (c) 2019 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 import { Command } from '@oclif/command'
 import * as Listr from 'listr'
 
@@ -17,7 +19,7 @@ import { KubeHelper } from '../api/kube'
 import { OpenShiftHelper } from '../api/openshift'
 import { VersionHelper } from '../api/version'
 import { CHE_OPERATOR_SELECTOR, DOC_LINK, DOC_LINK_RELEASE_NOTES, OUTPUT_SEPARATOR } from '../constants'
-import { base64Decode } from '../util'
+import { base64Decode, newError } from '../util'
 
 import { KubeTasks } from './kube'
 
@@ -26,29 +28,39 @@ import { KubeTasks } from './kube'
  */
 export class CheTasks {
   kube: KubeHelper
+
   kubeTasks: KubeTasks
+
   oc = new OpenShiftHelper()
+
   che: CheHelper
 
   cheNamespace: string
 
   cheAccessToken: string | undefined
+
   cheSelector = 'app=codeready,component=codeready'
+
   cheDeploymentName: string
 
   dashboardDeploymentName = 'che-dashboard'
+
   dashboardSelector = 'app=codeready,component=codeready-dashboard'
 
   keycloakDeploymentName = 'keycloak'
+
   keycloakSelector = 'app=codeready,component=keycloak'
 
   postgresDeploymentName = 'postgres'
+
   postgresSelector = 'app=codeready,component=postgres'
 
   devfileRegistryDeploymentName = 'devfile-registry'
+
   devfileRegistrySelector = 'app=codeready,component=devfile-registry'
 
   pluginRegistryDeploymentName = 'plugin-registry'
+
   pluginRegistrySelector = 'app=codeready,component=plugin-registry'
 
   cheConsoleLinkName = 'che'
@@ -76,34 +88,34 @@ export class CheTasks {
       {
         title: 'PostgreSQL pod bootstrap',
         enabled: ctx => ctx.isPostgresDeployed && !ctx.isPostgresReady,
-        task: () => this.kubeTasks.podStartTasks(this.postgresSelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.postgresSelector, this.cheNamespace),
       },
       {
         title: 'Keycloak pod bootstrap',
         enabled: ctx => ctx.isKeycloakDeployed && !ctx.isKeycloakReady,
-        task: () => this.kubeTasks.podStartTasks(this.keycloakSelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.keycloakSelector, this.cheNamespace),
       },
       {
         title: 'Devfile Registry pod bootstrap',
         enabled: ctx => ctx.isDevfileRegistryDeployed && !ctx.isDevfileRegistryReady,
-        task: () => this.kubeTasks.podStartTasks(this.devfileRegistrySelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.devfileRegistrySelector, this.cheNamespace),
       },
       {
         title: 'Plug-in Registry pod bootstrap',
         enabled: ctx => ctx.isPluginRegistryDeployed && !ctx.isPluginRegistryReady,
-        task: () => this.kubeTasks.podStartTasks(this.pluginRegistrySelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.pluginRegistrySelector, this.cheNamespace),
       },
       {
         title: 'CodeReady Workspaces Dashboard pod bootstrap',
         enabled: ctx => ctx.isDashboardDeployed && !ctx.isDashboardReady,
-        task: () => this.kubeTasks.podStartTasks(this.dashboardSelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.dashboardSelector, this.cheNamespace),
       },
       {
         title: 'CodeReady Workspaces Server pod bootstrap',
         enabled: ctx => !ctx.isCheReady,
-        task: () => this.kubeTasks.podStartTasks(this.cheSelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.cheSelector, this.cheNamespace),
       },
-      ...this.checkEclipseCheStatus()
+      ...this.checkEclipseCheStatus(),
     ]
   }
 
@@ -114,7 +126,7 @@ export class CheTasks {
    * is[Component]Deployed, is[Component]Stopped, is[Component]Ready
    * where component is one the: Che, Keycloak, Postgres, PluginRegistry, DevfileRegistry
    */
-  checkIfCheIsInstalledTasks(_flags: any, command: Command): ReadonlyArray<Listr.ListrTask> {
+  checkIfCheIsInstalledTasks(_flags: any): ReadonlyArray<Listr.ListrTask> {
     return [
       {
         title: `Verify if CodeReady Workspaces is deployed into namespace \"${this.cheNamespace}\"`,
@@ -175,31 +187,31 @@ export class CheTasks {
               {
                 enabled: () => ctx.isCheDeployed,
                 title: `Found ${ctx.isCheStopped ? 'stopped' : 'running'} CodeReady Workspaces deployment`,
-                task: () => { }
+                task: () => { },
               },
               {
                 enabled: () => ctx.isPostgresDeployed,
                 title: `Found ${ctx.isPostgresStopped ? 'stopped' : 'running'} postgres deployment`,
-                task: () => { }
+                task: () => { },
               },
               {
                 enabled: () => ctx.isKeycloakDeployed,
                 title: `Found ${ctx.isKeycloakStopped ? 'stopped' : 'running'} keycloak deployment`,
-                task: () => { }
+                task: () => { },
               },
               {
                 enabled: () => ctx.isPluginRegistryDeployed,
                 title: `Found ${ctx.isPluginRegistryStopped ? 'stopped' : 'running'} plugin registry deployment`,
-                task: () => { }
+                task: () => { },
               },
               {
                 enabled: () => ctx.isDevfileRegistryDeployed,
                 title: `Found ${ctx.isDevfileRegistryStopped ? 'stopped' : 'running'} devfile registry deployment`,
-                task: () => { }
-              }
+                task: () => { },
+              },
             ])
           }
-        }
+        },
       },
       {
         title: 'Check CodeReady Workspaces server status',
@@ -214,10 +226,10 @@ export class CheTasks {
             const auth = ctx.isAuthEnabled ? '(auth enabled)' : '(auth disabled)'
             task.title = `${task.title}...${status} ${auth}`
           } catch (error) {
-            command.error(`E_CHECK_CHE_STATUS_FAIL - Failed to check CodeReady Workspaces status (URL: ${cheURL}). ${error.message}`)
+            return newError(`Failed to check CodeReady Workspaces status (URL: ${cheURL}).`, error)
           }
-        }
-      }
+        },
+      },
     ]
   }
 
@@ -235,7 +247,7 @@ export class CheTasks {
         task: async () => {
           await this.kube.scaleDeployment(this.postgresDeploymentName, this.cheNamespace, 1)
           return this.kubeTasks.podStartTasks(this.postgresSelector, this.cheNamespace)
-        }
+        },
       },
       {
         title: 'Keycloak pod bootstrap',
@@ -243,7 +255,7 @@ export class CheTasks {
         task: async () => {
           await this.kube.scaleDeployment(this.keycloakDeploymentName, this.cheNamespace, 1)
           return this.kubeTasks.podStartTasks(this.keycloakSelector, this.cheNamespace)
-        }
+        },
       },
       {
         title: 'Devfile registry pod bootstrap',
@@ -251,7 +263,7 @@ export class CheTasks {
         task: async () => {
           await this.kube.scaleDeployment(this.devfileRegistryDeploymentName, this.cheNamespace, 1)
           return this.kubeTasks.podStartTasks(this.devfileRegistrySelector, this.cheNamespace)
-        }
+        },
       },
       {
         title: 'Plug-in Registry pod bootstrap',
@@ -259,7 +271,7 @@ export class CheTasks {
         task: async () => {
           await this.kube.scaleDeployment(this.pluginRegistryDeploymentName, this.cheNamespace, 1)
           return this.kubeTasks.podStartTasks(this.pluginRegistrySelector, this.cheNamespace)
-        }
+        },
       },
       {
         title: 'CodeReady Workspaces Dashboard pod bootstrap',
@@ -267,7 +279,7 @@ export class CheTasks {
         task: async () => {
           await this.kube.scaleDeployment(this.dashboardDeploymentName, this.cheNamespace, 1)
           return this.kubeTasks.podStartTasks(this.dashboardSelector, this.cheNamespace)
-        }
+        },
       },
       {
         title: 'CodeReady Workspaces Server pod bootstrap',
@@ -275,9 +287,9 @@ export class CheTasks {
         task: async () => {
           await this.kube.scaleDeployment(this.cheDeploymentName, this.cheNamespace, 1)
           return this.kubeTasks.podStartTasks(this.cheSelector, this.cheNamespace)
-        }
+        },
       },
-      ...this.checkEclipseCheStatus()
+      ...this.checkEclipseCheStatus(),
     ]
   }
 
@@ -287,7 +299,7 @@ export class CheTasks {
    *
    * @see [CheTasks](#checkIfCheIsInstalledTasks)
    */
-  scaleCheDownTasks(command: Command): ReadonlyArray<Listr.ListrTask> {
+  scaleCheDownTasks(): ReadonlyArray<Listr.ListrTask> {
     return [{
       title: 'Stop CodeReady Workspaces Server and wait until it\'s ready to shutdown',
       enabled: (ctx: any) => !ctx.isCheStopped,
@@ -304,9 +316,9 @@ export class CheTasks {
           await cheApi.waitUntilCheServerReadyToShutdown()
           task.title = `${task.title}...done`
         } catch (error) {
-          command.error(`E_SHUTDOWN_CHE_SERVER_FAIL - Failed to shutdown CodeReady Workspaces server. ${error.message}`)
+          return newError('Failed to shutdown CodeReady Workspaces server.', error)
         }
-      }
+      },
     },
     {
       title: `Scale \"${this.cheDeploymentName}\" deployment to zero`,
@@ -316,9 +328,9 @@ export class CheTasks {
           await this.kube.scaleDeployment(this.cheDeploymentName, this.cheNamespace, 0)
           task.title = await `${task.title}...done`
         } catch (error) {
-          command.error(`E_SCALE_DEPLOY_FAIL - Failed to scale deployment. ${error.message}`)
+          return newError(`Failed to scale ${this.cheDeploymentName} deployment.`, error)
         }
-      }
+      },
     },
     {
       title: 'Scale \"dashboard\" deployment to zero',
@@ -328,9 +340,9 @@ export class CheTasks {
           await this.kube.scaleDeployment(this.dashboardDeploymentName, this.cheNamespace, 0)
           task.title = await `${task.title}...done`
         } catch (error) {
-          command.error(`E_SCALE_DEPLOY_FAIL - Failed to scale dashboard deployment. ${error.message}`)
+          return newError('Failed to scale dashboard deployment.', error)
         }
-      }
+      },
     },
     {
       title: 'Scale \"keycloak\" deployment to zero',
@@ -340,9 +352,9 @@ export class CheTasks {
           await this.kube.scaleDeployment(this.keycloakDeploymentName, this.cheNamespace, 0)
           task.title = await `${task.title}...done`
         } catch (error) {
-          command.error(`E_SCALE_DEPLOY_FAIL - Failed to scale keycloak deployment. ${error.message}`)
+          return newError('Failed to scale keycloak deployment.', error)
         }
-      }
+      },
     },
     {
       title: 'Scale \"postgres\" deployment to zero',
@@ -352,9 +364,9 @@ export class CheTasks {
           await this.kube.scaleDeployment(this.postgresDeploymentName, this.cheNamespace, 0)
           task.title = await `${task.title}...done`
         } catch (error) {
-          command.error(`E_SCALE_DEPLOY_FAIL - Failed to scale postgres deployment. ${error.message}`)
+          return newError('Failed to scale postgres deployment.', error)
         }
-      }
+      },
     },
     {
       title: 'Scale \"devfile registry\" deployment to zero',
@@ -364,9 +376,9 @@ export class CheTasks {
           await this.kube.scaleDeployment(this.devfileRegistryDeploymentName, this.cheNamespace, 0)
           task.title = await `${task.title}...done`
         } catch (error) {
-          command.error(`E_SCALE_DEPLOY_FAIL - Failed to scale devfile-registry deployment. ${error.message}`)
+          return newError('Failed to scale devfile registry deployment.', error)
         }
-      }
+      },
     },
     {
       title: 'Scale \"plugin registry\" deployment to zero',
@@ -376,9 +388,9 @@ export class CheTasks {
           await this.kube.scaleDeployment(this.pluginRegistryDeploymentName, this.cheNamespace, 0)
           task.title = await `${task.title}...done`
         } catch (error) {
-          command.error(`E_SCALE_DEPLOY_FAIL - Failed to scale plugin-registry deployment. ${error.message}`)
+          return newError('Failed to scale plugin registry deployment.', error)
         }
-      }
+      },
     }]
   }
 
@@ -392,14 +404,14 @@ export class CheTasks {
         task: async (_ctx: any, task: any) => {
           await this.kube.deleteAllDeployments(flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete all services',
         task: async (_ctx: any, task: any) => {
           await this.kube.deleteAllServices(flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete all ingresses',
@@ -407,7 +419,7 @@ export class CheTasks {
         task: async (_ctx: any, task: any) => {
           await this.kube.deleteAllIngresses(flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete all routes',
@@ -415,7 +427,7 @@ export class CheTasks {
         task: async (_ctx: any, task: any) => {
           await this.oc.deleteAllRoutes(flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete configmaps for CodeReady Workspaces server and operator',
@@ -423,7 +435,7 @@ export class CheTasks {
           await this.kube.deleteConfigMap('che', flags.chenamespace)
           await this.kube.deleteConfigMap('codeready-operator', flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete rolebindings che, che-workspace-exec and che-workspace-view',
@@ -433,7 +445,7 @@ export class CheTasks {
           await this.kube.deleteRoleBinding('che-workspace-exec', flags.chenamespace)
           await this.kube.deleteRoleBinding('che-workspace-view', flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete service accounts che, che-workspace',
@@ -441,7 +453,7 @@ export class CheTasks {
           await this.kube.deleteServiceAccount('che', flags.chenamespace)
           await this.kube.deleteServiceAccount('che-workspace', flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete PVCs',
@@ -451,7 +463,7 @@ export class CheTasks {
           await this.kube.deletePersistentVolumeClaim('keycloak-data', flags.chenamespace)
           await this.kube.deletePersistentVolumeClaim('keycloak-log', flags.chenamespace)
           task.title = `${task.title}...OK`
-        }
+        },
       },
       {
         title: `Delete consoleLink ${this.cheConsoleLinkName}`,
@@ -462,8 +474,9 @@ export class CheTasks {
             await this.kube.deleteConsoleLink(this.cheConsoleLinkName)
           }
           task.title = `${task.title}...OK`
-        }
-      }]
+        },
+      },
+    ]
   }
 
   /**
@@ -476,43 +489,43 @@ export class CheTasks {
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.cheSelector, this.cheNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Wait until CodeReady Workspaces Dashboard pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.dashboardSelector, this.cheNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Wait until Keycloak pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.keycloakSelector, this.cheNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Wait until PostgreSQL pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.postgresSelector, this.cheNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Wait until Devfile Registry pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.devfileRegistrySelector, this.cheNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Wait until Plug-in Registry pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.pluginRegistrySelector, this.cheNamespace)
           task.title = `${task.title}...done.`
-        }
-      }
+        },
+      },
     ]
   }
 
@@ -525,7 +538,7 @@ export class CheTasks {
           await this.kube.deleteNamespace(flags.chenamespace)
         }
         task.title = `${task.title}...OK`
-      }
+      },
     }]
   }
 
@@ -536,7 +549,7 @@ export class CheTasks {
         if (!await this.kube.getNamespace(flags.chenamespace)) {
           command.error(`E_BAD_NS - Namespace does not exist.\nThe Kubernetes Namespace "${flags.chenamespace}" doesn't exist.`, { code: 'EBADNS' })
         }
-      }
+      },
     }]
   }
 
@@ -548,7 +561,7 @@ export class CheTasks {
       title: 'Verify if the workspaces is running',
       task: async (ctx: any) => {
         ctx.pod = await this.che.getWorkspacePodName(flags.chenamespace!, flags.workspace).catch(e => command.error(e.message))
-      }
+      },
     }]
   }
 
@@ -563,57 +576,57 @@ export class CheTasks {
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, CHE_OPERATOR_SELECTOR, ctx.directory, follow)
           task.title = `${task.title}...done`
-        }
+        },
       },
       {
         title: `${follow ? 'Start following' : 'Read'} CodeReady Workspaces Server logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.cheSelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
-        }
+        },
       },
       {
         title: `${follow ? 'Start following' : 'Read'} PostgreSQL logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.postgresSelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
-        }
+        },
       },
       {
         title: `${follow ? 'Start following' : 'Read'} Keycloak logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.keycloakSelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
-        }
+        },
       },
       {
         title: `${follow ? 'Start following' : 'Read'} Plug-in Registry logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.pluginRegistrySelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
-        }
+        },
       },
       {
         title: `${follow ? 'Start following' : 'Read'} Devfile Registry logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.devfileRegistrySelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
-        }
+        },
       },
       {
         title: `${follow ? 'Start following' : 'Read'} CodeReady Workspaces Dashboard logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.dashboardSelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
-        }
+        },
       },
       {
         title: `${follow ? 'Start following' : 'Read'} namespace events`,
         task: async (ctx: any, task: any) => {
           await this.che.readNamespaceEvents(flags.chenamespace, ctx.directory, follow)
           task.title = await `${task.title}...done`
-        }
-      }
+        },
+      },
     ]
   }
 
@@ -628,7 +641,7 @@ export class CheTasks {
           }
           ctx.podName = chePods.items[0].metadata!.name!
           task.title = `${task.title}...done`
-        }
+        },
       },
       {
         title: 'Check if debug mode is enabled',
@@ -639,15 +652,15 @@ export class CheTasks {
           }
 
           task.title = `${task.title}...done`
-        }
+        },
       },
       {
         title: `Forward port '${flags['debug-port']}'`,
         task: async (ctx: any, task: any) => {
           await this.kube.portForward(ctx.podName, flags.chenamespace, flags['debug-port'])
           task.title = `${task.title}...done`
-        }
-      }
+        },
+      },
     ]
   }
 
@@ -718,8 +731,8 @@ export class CheTasks {
           }
           ctx.highlightedMessages = messages.concat(ctx.highlightedMessages)
           task.title = `${task.title}...done`
-        }
-      }
+        },
+      },
     ]
   }
 
@@ -731,9 +744,8 @@ export class CheTasks {
           const cheApi = CheApiClient.getInstance(ctx.cheURL + '/api')
           task.title = `${task.title}...done`
           return cheApi.isCheServerReady()
-        }
-      }
+        },
+      },
     ]
   }
-
 }
